@@ -12,62 +12,62 @@ use Carp ();
 our $VERSION = '2.26';
 our %LEVELS;
 
-
-BEGIN
-{
-    foreach my $l ( qw( debug info notice warn warning err error crit critical alert emerg emergency ) )
-    {
-        my $sub = sub { my $self = shift;
-                        $self->log( level => $l, message => "@_" ); };
+BEGIN {
+    foreach my $l (
+        qw( debug info notice warn warning err error crit critical alert emerg emergency )
+        ) {
+        my $sub = sub {
+            my $self = shift;
+            $self->log( level => $l, message => "@_" );
+        };
 
         $LEVELS{$l} = 1;
 
         no strict 'refs';
-        *{$l} = $sub
+        *{$l} = $sub;
     }
 }
 
-sub new
-{
+sub new {
     my $proto = shift;
     my $class = ref $proto || $proto;
 
-    my %p = validate_with
-        ( params => \@_,
-          spec => { outputs => { type => ARRAYREF, optional => 1 },
-                    callbacks => { type => ARRAYREF | CODEREF, optional => 1 }},
-          allow_extra => 1,  # for backward compatibility
-        );
+    my %p = validate_with(
+        params => \@_,
+        spec   => {
+            outputs   => { type => ARRAYREF,           optional => 1 },
+            callbacks => { type => ARRAYREF | CODEREF, optional => 1 }
+        },
+        allow_extra => 1,    # for backward compatibility
+    );
 
     my $self = bless {}, $class;
 
     my @cb = $self->_get_callbacks(%p);
     $self->{callbacks} = \@cb if @cb;
 
-    if ( my $outputs = $p{outputs} )
-    {
-        if ( ref $outputs->[1] eq 'HASH' )
-        {
+    if ( my $outputs = $p{outputs} ) {
+        if ( ref $outputs->[1] eq 'HASH' ) {
+
             # 2.23 API
             # outputs => [
-            #   File => {min_level => 'debug', filename => 'logfile' },
-            #   Screen => {min_level => 'warning' }
+            #   File => { min_level => 'debug', filename => 'logfile' },
+            #   Screen => { min_level => 'warning' }
             # ]
-            while ( my ( $class, $params ) = splice @$outputs, 0, 2 )
-            {
+            while ( my ( $class, $params ) = splice @$outputs, 0, 2 ) {
                 $self->_add_output( $class, %$params );
             }
         }
-        else
-        {
+        else {
+
             # 2.24+ syntax
             # outputs => [
             #   [ 'File',   min_level => 'debug', filename => 'logfile' ],
             #   [ 'Screen', min_level => 'warning' ]
             # ]
-            foreach my $arr (@$outputs)
-            {
-                die "expected arrayref, not '$arr'" unless ref $arr eq 'ARRAY';
+            foreach my $arr (@$outputs) {
+                die "expected arrayref, not '$arr'"
+                    unless ref $arr eq 'ARRAY';
                 $self->_add_output(@$arr);
             }
         }
@@ -76,55 +76,54 @@ sub new
     return $self;
 }
 
-sub _add_output
-{
-    my $self = shift;
+sub _add_output {
+    my $self  = shift;
     my $class = shift;
 
-    my $full_class =
-        substr( $class, 0, 1 ) eq '+' ? substr( $class, 1 ) : "Log::Dispatch::$class";
+    my $full_class
+        = substr( $class, 0, 1 ) eq '+'
+        ? substr( $class, 1 )
+        : "Log::Dispatch::$class";
 
     _require_dynamic($full_class);
 
     $self->add( $full_class->new(@_) );
 }
 
-sub add
-{
-    my $self = shift;
+sub add {
+    my $self   = shift;
     my $object = shift;
 
     # Once 5.6 is more established start using the warnings module.
-    if (exists $self->{outputs}{$object->name} && $^W)
-    {
-        Carp::carp("Log::Dispatch::* object ", $object->name, " already exists.");
+    if ( exists $self->{outputs}{ $object->name } && $^W ) {
+        Carp::carp(
+            "Log::Dispatch::* object ", $object->name,
+            " already exists."
+        );
     }
 
-    $self->{outputs}{$object->name} = $object;
+    $self->{outputs}{ $object->name } = $object;
 }
 
-sub remove
-{
+sub remove {
     my $self = shift;
     my $name = shift;
 
     return delete $self->{outputs}{$name};
 }
 
-sub log
-{
+sub log {
     my $self = shift;
-    my %p = @_;
+    my %p    = @_;
 
     return unless $self->would_log( $p{level} );
 
     $self->_log_to_outputs( $self->_prepare_message(%p) );
 }
 
-sub _prepare_message
-{
+sub _prepare_message {
     my $self = shift;
-    my %p = @_;
+    my %p    = @_;
 
     $p{message} = $p{message}->()
         if ref $p{message} eq 'CODE';
@@ -135,53 +134,47 @@ sub _prepare_message
     return %p;
 }
 
-sub _log_to_outputs
-{
+sub _log_to_outputs {
     my $self = shift;
-    my %p = @_;
+    my %p    = @_;
 
-    foreach (keys %{ $self->{outputs} })
-    {
+    foreach ( keys %{ $self->{outputs} } ) {
         $p{name} = $_;
         $self->_log_to(%p);
     }
 }
 
-sub log_and_die
-{
+sub log_and_die {
     my $self = shift;
 
     my %p = $self->_prepare_message(@_);
 
-    $self->_log_to_outputs(%p) if $self->would_log($p{level});
+    $self->_log_to_outputs(%p) if $self->would_log( $p{level} );
 
     $self->_die_with_message(%p);
 }
 
-sub log_and_croak
-{
+sub log_and_croak {
     my $self = shift;
 
     $self->log_and_die( @_, carp_level => 3 );
 }
 
-sub _die_with_message
-{
+sub _die_with_message {
     my $self = shift;
-    my %p = @_;
+    my %p    = @_;
 
     my $msg = $p{message};
 
-    local $Carp::CarpLevel = ($Carp::CarpLevel || 0) + $p{carp_level}
-	if exists $p{carp_level};
+    local $Carp::CarpLevel = ( $Carp::CarpLevel || 0 ) + $p{carp_level}
+        if exists $p{carp_level};
 
     Carp::croak($msg);
 }
 
-sub log_to
-{
+sub log_to {
     my $self = shift;
-    my %p = @_;
+    my %p    = @_;
 
     $p{message} = $self->_apply_callbacks(%p)
         if $self->{callbacks};
@@ -189,24 +182,21 @@ sub log_to
     $self->_log_to(%p);
 }
 
-sub _log_to
-{
+sub _log_to {
     my $self = shift;
-    my %p = @_;
+    my %p    = @_;
     my $name = $p{name};
 
-    if (exists $self->{outputs}{$name})
-    {
+    if ( exists $self->{outputs}{$name} ) {
         $self->{outputs}{$name}->log(@_);
     }
-    elsif ($^W)
-    {
-        Carp::carp("Log::Dispatch::* object named '$name' not in dispatcher\n");
+    elsif ($^W) {
+        Carp::carp(
+            "Log::Dispatch::* object named '$name' not in dispatcher\n");
     }
 }
 
-sub output
-{
+sub output {
     my $self = shift;
     my $name = shift;
 
@@ -215,29 +205,25 @@ sub output
     return $self->{outputs}{$name};
 }
 
-sub level_is_valid
-{
+sub level_is_valid {
     shift;
     return $LEVELS{ shift() };
 }
 
-sub would_log
-{
-    my $self = shift;
+sub would_log {
+    my $self  = shift;
     my $level = shift;
 
     return 0 unless $self->level_is_valid($level);
 
-    foreach ( values %{ $self->{outputs} } )
-    {
+    foreach ( values %{ $self->{outputs} } ) {
         return 1 if $_->_should_log($level);
     }
 
     return 0;
 }
 
-sub _require_dynamic
-{
+sub _require_dynamic {
     my ($class) = @_;
 
     local $@;
@@ -247,47 +233,56 @@ sub _require_dynamic
 
 1;
 
-__END__
+# ABSTRACT: Dispatches messages to one or more outputs
+
+
+
+=pod
 
 =head1 NAME
 
 Log::Dispatch - Dispatches messages to one or more outputs
 
+=head1 VERSION
+
+version 2.27
+
 =head1 SYNOPSIS
 
-   use Log::Dispatch;
+  use Log::Dispatch;
 
-   # Simple API
-   #
-   my $log =
-       Log::Dispatch->new
-           ( outputs =>
-                 [ [ 'File',   min_level => 'debug', filename => 'logfile' ],
-                   [ 'Screen', min_level => 'warning' ],
-                 ],
-           );
+  # Simple API
+  #
+  my $log = Log::Dispatch->new(
+      outputs => [
+          [ 'File',   min_level => 'debug', filename => 'logfile' ],
+          [ 'Screen', min_level => 'warning' ],
+      ],
+  );
 
-   $log->info('Blah, blah');
+  $log->info('Blah, blah');
 
-   # More verbose API
-   #
-   my $log = Log::Dispatch->new();
-   $log->add( Log::Dispatch::File->new
-                         ( name      => 'file1',
-                           min_level => 'debug',
-                           filename  => 'logfile'
-                         )
-                   );
-   $log->add( Log::Dispatch::Screen->new
-                         ( name      => 'screen',
-                           min_level => 'warning',
-                         )
-                   );
+  # More verbose API
+  #
+  my $log = Log::Dispatch->new();
+  $log->add(
+      Log::Dispatch::File->new(
+          name      => 'file1',
+          min_level => 'debug',
+          filename  => 'logfile'
+      )
+  );
+  $log->add(
+      Log::Dispatch::Screen->new(
+          name      => 'screen',
+          min_level => 'warning',
+      )
+  );
 
-   $log->log( level => 'info', message => 'Blah, blah' );
+  $log->log( level => 'info', message => 'Blah, blah' );
 
-   my $sub = sub { my %p = @_; return reverse $p{message}; };
-   my $reversing_dispatcher = Log::Dispatch->new( callbacks => $sub );
+  my $sub = sub { my %p = @_; return reverse $p{message}; };
+  my $reversing_dispatcher = Log::Dispatch->new( callbacks => $sub );
 
 =head1 DESCRIPTION
 
@@ -377,14 +372,14 @@ translates to:
 
  $log->log( level => 'alert', message => 'Strange data in incoming request' );
 
-These methods act like Perl's C<print> built-in when given a list of
-arguments.  Thus, the following calls are equivalent:
+If you pass an array to these methods, it will be stringified as is:
 
  my @array = ('Something', 'bad', 'is', here');
  $log->alert(@array);
 
- my $scalar = "@array";
- $log->alert($scalar);
+ # is equivalent to
+
+ $log->alert("@array");
 
 =item * log_and_die( level => $, message => $ or \& )
 
@@ -591,8 +586,10 @@ Written by Arthur Bergman.  Logs messages to the Windows event log.
 
 =head2 Log::Log4perl
 
-An implementation of Java's log4j API in Perl, using Log::Dispatch to
-do the actual logging.  Created by Mike Schilli and Kevin Goess.
+An implementation of Java's log4j API in Perl. Log messages can be limited by
+fine-grained controls, and if they end up being logged, both native Log4perl
+and Log::Dispatch appenders can be used to perform the actual logging
+job. Created by Mike Schilli and Kevin Goess.
 
 =head2 Log::Dispatch::Config
 
@@ -615,19 +612,6 @@ Support questions can be sent to me at my email address, shown below.
 
 The code repository is at http://hg.urth.org/hg/Log-Dispatch.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 1999-2009 David Rolsky.  All rights reserved.  This program is
-free software; you can redistribute it and/or modify it under the same terms
-as Perl itself.
-
-The full text of the license can be found in the LICENSE file included with
-this module.
-
 =head1 SEE ALSO
 
 L<Log::Dispatch::ApacheLog>, L<Log::Dispatch::Email>,
@@ -637,4 +621,20 @@ L<Log::Dispatch::File>, L<Log::Dispatch::File::Locked>,
 L<Log::Dispatch::Handle>, L<Log::Dispatch::Output>, L<Log::Dispatch::Screen>,
 L<Log::Dispatch::Syslog>
 
+=head1 AUTHOR
+
+Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
+
 =cut
+
+
+__END__
+
