@@ -1,4 +1,7 @@
 package Log::Dispatch::Syslog;
+BEGIN {
+  $Log::Dispatch::Syslog::VERSION = '2.27';
+}
 
 use strict;
 use warnings;
@@ -7,15 +10,12 @@ use Log::Dispatch::Output;
 
 use base qw( Log::Dispatch::Output );
 
-use Params::Validate qw(validate SCALAR);
+use Params::Validate qw(validate ARRAYREF SCALAR);
 Params::Validate::validation_options( allow_extra => 1 );
 
 use Sys::Syslog 0.16 ();
 
-our $VERSION = '2.26';
-
-sub new
-{
+sub new {
     my $proto = shift;
     my $class = ref $proto || $proto;
 
@@ -30,78 +30,101 @@ sub new
 }
 
 my ($Ident) = $0 =~ /(.+)/;
-sub _init
-{
+
+sub _init {
     my $self = shift;
 
-    my %p = validate( @_, { ident    => { type => SCALAR,
-                                          default => $Ident },
-                            logopt   => { type => SCALAR,
-                                          default => '' },
-                            facility => { type => SCALAR,
-                                          default => 'user' },
-                            socket   => { type => SCALAR,
-                                          default => undef },
-                          } );
+    my %p = validate(
+        @_, {
+            ident => {
+                type    => SCALAR,
+                default => $Ident
+            },
+            logopt => {
+                type    => SCALAR,
+                default => ''
+            },
+            facility => {
+                type    => SCALAR,
+                default => 'user'
+            },
+            socket => {
+                type    => SCALAR | ARRAYREF,
+                default => undef
+            },
+        }
+    );
 
     $self->{ident}    = $p{ident};
     $self->{logopt}   = $p{logopt};
     $self->{facility} = $p{facility};
     $self->{socket}   = $p{socket};
 
-    $self->{priorities} = [ 'DEBUG',
-                            'INFO',
-                            'NOTICE',
-                            'WARNING',
-                            'ERR',
-                            'CRIT',
-                            'ALERT',
-                            'EMERG' ];
+    $self->{priorities} = [
+        'DEBUG',
+        'INFO',
+        'NOTICE',
+        'WARNING',
+        'ERR',
+        'CRIT',
+        'ALERT',
+        'EMERG'
+    ];
 
-    Sys::Syslog::setlogsock( $self->{socket} )
+    Sys::Syslog::setlogsock(
+        ref $self->{socket} ? @{ $self->{socket} } : $self->{socket} )
         if defined $self->{socket};
 }
 
-sub log_message
-{
+sub log_message {
     my $self = shift;
-    my %p = @_;
+    my %p    = @_;
 
-    my $pri = $self->_level_as_number($p{level});
+    my $pri = $self->_level_as_number( $p{level} );
 
-    eval
-    {
-        Sys::Syslog::openlog($self->{ident}, $self->{logopt}, $self->{facility});
-        Sys::Syslog::syslog($self->{priorities}[$pri], $p{message});
+    eval {
+        Sys::Syslog::openlog(
+            $self->{ident}, $self->{logopt},
+            $self->{facility}
+        );
+        Sys::Syslog::syslog( $self->{priorities}[$pri], $p{message} );
         Sys::Syslog::closelog;
     };
 
     warn $@ if $@ and $^W;
 }
 
-
 1;
 
-__END__
+# ABSTRACT: Object for logging to system log.
+
+
+
+=pod
 
 =head1 NAME
 
 Log::Dispatch::Syslog - Object for logging to system log.
 
+=head1 VERSION
+
+version 2.27
+
 =head1 SYNOPSIS
 
   use Log::Dispatch;
 
-  my $log =
-      Log::Dispatch->new
-          ( outputs =>
-                [ [ 'Syslog',
-                    min_level => 'info',
-                    ident => 'Yadda yadda' ]
-                ]
-          );
+  my $log = Log::Dispatch->new(
+      outputs => [
+          [
+              'Syslog',
+              min_level => 'info',
+              ident     => 'Yadda yadda'
+          ]
+      ]
+  );
 
-  $log->emerg( "Time to die." );
+  $log->emerg("Time to die.");
 
 =head1 DESCRIPTION
 
@@ -137,7 +160,7 @@ Valid options are 'auth', 'authpriv', 'cron', 'daemon', 'kern',
 'local0' through 'local7', 'mail, 'news', 'syslog', 'user',
 'uucp'.  Defaults to 'user'
 
-=item * socket ($)
+=item * socket ($ or \@)
 
 Tells what type of socket to use for sending syslog messages.  Valid
 options are listed in C<Sys::Syslog>.
@@ -146,10 +169,25 @@ If you don't provide this, then we let C<Sys::Syslog> simply pick one
 that works, which is the preferred option, as it makes your code more
 portable.
 
+If you pass an array reference, it is dereferenced and passed to
+C<Sys::Syslog::setlogsock()>.
+
 =back
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
